@@ -1,11 +1,14 @@
 try:
     from jinja2 import Template
 except ImportError:
-    from string import Template
+    from string import Template  # type: ignore
 
-from commitizen import defaults
+from typing import Any, Dict, List, Optional
+
+from commitizen import defaults, out
 from commitizen.config import BaseConfig
 from commitizen.cz.base import BaseCommitizen
+from commitizen.error_codes import MISSING_CONFIG
 
 __all__ = ["CustomizeCommitsCz"]
 
@@ -16,7 +19,11 @@ class CustomizeCommitsCz(BaseCommitizen):
 
     def __init__(self, config: BaseConfig):
         super(CustomizeCommitsCz, self).__init__(config)
-        self.custom_settings = self.config.settings.get("customize")
+
+        if "customize" not in self.config.settings:
+            out.error("fatal: customize is not set in configuration file.")
+            raise SystemExit(MISSING_CONFIG)
+        self.custom_settings = self.config.settings["customize"]
 
         custom_bump_pattern = self.custom_settings.get("bump_pattern")
         if custom_bump_pattern:
@@ -26,23 +33,23 @@ class CustomizeCommitsCz(BaseCommitizen):
         if custom_bump_map:
             self.bump_map = custom_bump_map
 
-    def questions(self) -> list:
+    def questions(self) -> List[Dict[str, Any]]:
         return self.custom_settings.get("questions")
 
     def message(self, answers: dict) -> str:
         message_template = Template(self.custom_settings.get("message_template"))
         if getattr(Template, "substitute", None):
-            return message_template.substitute(**answers)
+            return message_template.substitute(**answers)  # type: ignore
         else:
             return message_template.render(**answers)
 
-    def example(self) -> str:
+    def example(self) -> Optional[str]:
         return self.custom_settings.get("example")
 
-    def schema(self) -> str:
+    def schema(self) -> Optional[str]:
         return self.custom_settings.get("schema")
 
-    def info(self) -> str:
+    def info(self) -> Optional[str]:
         info_path = self.custom_settings.get("info_path")
         info = self.custom_settings.get("info")
         if info_path:
@@ -51,3 +58,4 @@ class CustomizeCommitsCz(BaseCommitizen):
             return content
         elif info:
             return info
+        return None
